@@ -21,6 +21,25 @@ class _TestGeneral:
             thetas=thetas
         )
 
+    def test_set_int_to_list(self):
+        """Test that setting int to list"""
+        num_test = self.class_name._set_int_to_list(1)
+        list_test = self.class_name._set_int_to_list([2])
+        assert isinstance(num_test, list)
+        assert isinstance(list_test, list)
+        assert num_test[0] == 1
+        assert list_test[0] == 2
+
+    def test_create_range_multiple_arguments_exception(self, thetas):
+        """Test that passing multiple parameters raises an error"""
+        with pytest.raises(ValueError):
+            arr = self.class_name.create_range(
+                R=list(range(10)),
+                r=list(range(10)),
+                d=10,
+                thetas=thetas
+            )
+
     def test_custom_origin_offsets(self, thetas):
         """Test custom origin offsets"""
         base_obj = self.class_name(
@@ -104,6 +123,15 @@ class _TestSpecial:
             thetas=thetas
         )
 
+    def test_create_range_multiple_arguments_exception(self, thetas):
+        """Test that passing multiple parameters raises an error"""
+        with pytest.raises(ValueError):
+            arr = self.class_name.create_range(
+                R=list(range(10)),
+                r=list(range(10)),
+                thetas=thetas
+            )
+
     def test_custom_origin_offsets(self, thetas):
         """Test custom origin offsets vertically"""
         base_obj = self.class_name(
